******************
Nengo contributors
******************

This is a list of people who have contributed to Nengo.
Note that this is not the list of copyright holders;
Applied Brain Research Inc. holds the copyright to
all Nengo code, except for code that is used under
various licenses, as described in the ``LICENSE.rst`` file.

By adding your name to this file, you are agreeing
to the Contributor Assignment Agreement found in
the ``LICENSE.rst`` file. If you agree, then add yourself
to the file like so::

  - Name <email address>

Please keep this list sorted alphabetically.

- Aaron Voelker <arvoelke@gmail.com>
- Andrew Mundy <andrew.mundy@ieee.org>
- Ben Morcos <morcos.ben@gmail.com>
- Brent Komer <brent.komer@gmail.com>
- Bryan Tripp <bptripp@uwaterloo.ca>
- Chris Eliasmith <celiasmith@uwaterloo.ca>
- Daniel Rasmussen <drasmuss@uwaterloo.ca>
- Eric Crawford <e2crawfo@uwaterloo.ca>
- Eric Hunsberger <erichuns@gmail.com>
- Ivana Kajić <ivana.kajic@gmail.com>
- James Bergstra <james.bergstra@gmail.com>
- Jan Gosmann <jan@hyper-world.de>
- Oliver Trujillo <olivertgp@hotmail.com>
- Peter Blouw <pblouw@uwaterloo.ca>
- Peter Suma <psuma@waterloo.ca>
- Sean Aubin <seanaubin@gmail.com>
- Sugandha Sharma <sugandha974@gmail.com>
- Terry Stewart <terry.stewart@gmail.com>
- Travis DeWolf <travis.dewolf@gmail.com>
- Trevor Bekolay <tbekolay@gmail.com>
- Xuan Choo <xchoo.mainframe@gmail.com>
- Youssef Zaky <youssefzaky@gmail.com>
